package com.shigongli.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.shigongli.common.BaseController;
import com.shigongli.common.ResponseBean;
import com.shigongli.common.StringUtils;
import com.shigongli.constants.StatusConstant;
import com.shigongli.vo.HousePersonParams;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.shigongli.service.ITaHousePersonService;
import com.shigongli.entity.TaHousePerson;
import org.springframework.web.bind.annotation.RestController;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
    * 住房人 前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-11
 */

@Api(tags = "住房人")
@RestController
@RequestMapping("/")
public class TaHousePersonController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaHousePersonController.class);

    @Autowired
    public ITaHousePersonService iTaHousePersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taHousePerson",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taHousePersonList(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
									 @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize) throws Exception{

		    IPage<TaHousePerson> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaHousePerson> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaHousePerson> result = iTaHousePersonService.page(pg, queryWrapper);
            return ResponseBean.success(result);
    }

    /**
     * 保存入住人
     * @param housePersonParams 实体对象
     * @return
     */
    @RequestMapping(value="/ma/taHousePerson",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean taHousePersonAdd(@ApiParam("保存内容") @RequestBody HousePersonParams housePersonParams) throws Exception{

        if (null == housePersonParams) {
            return ResponseBean.error("请设置入住人员信息", ResponseBean.ERROR_MISSING_PARAMS);
        }

        if (StringUtils.isEmpty(housePersonParams.getHouseId()) || StringUtils.isEmpty(housePersonParams.getOrderId())) {
            return ResponseBean.error("请设置房源或订单信息", ResponseBean.ERROR_MISSING_PARAMS);
        }

        if (null == housePersonParams.getPersonList() || housePersonParams.getPersonList().size() < 1) {
            return ResponseBean.error("请设置入住人员信息", ResponseBean.ERROR_MISSING_PARAMS);
        }

        List<TaHousePerson> taHousePersonList = new ArrayList<>();
        for (HousePersonParams.Person person: housePersonParams.getPersonList()) {
            TaHousePerson taHousePerson = new TaHousePerson();
            taHousePerson.setHouseId(housePersonParams.getHouseId());
            taHousePerson.setOrderId(housePersonParams.getOrderId());
            taHousePerson.setPhone(person.getPhone());
            taHousePerson.setName(person.getName());
            taHousePerson.setStatus(StatusConstant.NORMAL);
            taHousePersonList.add(taHousePerson);
        }

        if (iTaHousePersonService.saveBatch(taHousePersonList)){
            return ResponseBean.success(taHousePersonList);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taHousePerson/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean taHousePersonDelete(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        if(iTaHousePersonService.removeById(id)){
            return ResponseBean.success("success");
        }else {
            return ResponseBean.error("删除失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taHousePerson 实体对象
     * @return
     */
    @RequestMapping(value="/taHousePerson/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean taHousePersonUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                        @ApiParam("更新内容") @RequestBody TaHousePerson taHousePerson) throws Exception{

        if (iTaHousePersonService.updateById(taHousePerson)){
            return ResponseBean.success(iTaHousePersonService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taHousePerson/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean taHousePersonGet(@ApiParam("对象ID") @PathVariable Integer id) throws Exception{
        return ResponseBean.success(iTaHousePersonService.getById(id));
    }
}
